@@ -664,7 +664,7 @@ void RGPreferencesWindow::readTreeViewValues()
    for(unsigned int i=0;i<columns.size();i++) {
       gtk_list_store_append (store, &iter);
       gtk_list_store_set (store, &iter,
-			  TREE_CHECKBOX_COLUMN, &columns[i].visible,
+			  TREE_CHECKBOX_COLUMN, columns[i].visible,
 			  TREE_NAME_COLUMN, columns[i].name,
 			  TREE_VISIBLE_NAME_COLUMN, _(columns[i].visible_name),
 			  -1);
